@@ -53,6 +53,9 @@ INTERNALERROR_INTERNALHTTPSERVERERROR = 'InternalError.InternalHttpServerError'
 # 内部组件访问错误。
 INTERNALERROR_INTERNALINNERCOMMONERROR = 'InternalError.InternalInnerCommonError'
 
+# 调用计费服务失败。
+INTERNALERROR_INTERNALTRADEERROR = 'InternalError.InternalTradeError'
+
 # 锁冲突。
 INTERNALERROR_LOCKERROR = 'InternalError.LockError'
 
@@ -83,6 +86,9 @@ INVALIDPARAMETERVALUE_DATACONVERTERROR = 'InvalidParameterValue.DataConvertError
 # 参数值错误。
 INVALIDPARAMETERVALUE_INVALIDPARAMETERVALUE = 'InvalidParameterValue.InvalidParameterValue'
 
+# 非法参数。
+INVALIDPARAMETERVALUE_INVALIDPARAMETERVALUEERROR = 'InvalidParameterValue.InvalidParameterValueError'
+
 # 闲置迁移任务数目超过限制。
 LIMITEXCEEDED_MAXUNUSEDJOBS = 'LimitExceeded.MaxUnusedJobs'
 
